@@ -12,8 +12,8 @@ log = QELogger()
 
 class Application:
     def __init__(self, component, a11y_app_name=None, desktop_file_exists=True,
-                 desktop_file_name="", desktop_file_path="", 
-                 app_process_name="", shell=None, session_type="", 
+                 desktop_file_name="", desktop_file_path="",
+                 app_process_name="", shell=None, session_type="",
                  session_desktop="", logging=False):
         """
         .. note::
@@ -72,7 +72,8 @@ class Application:
         self.app_process_name = app_process_name if app_process_name else component
         self.get_desktop_file_data()
 
-        self.preserve_old_api()
+        if 'Flatpak' not in f'{type(self)}':
+            self.preserve_old_api()
 
 
     def get_desktop_file_data(self):
@@ -101,7 +102,7 @@ class Application:
                     raise Exception(f"Desktop file of application '{self.component}' was not found.")
 
                 desktop_file = desktop_run[0].strip("\n")
-       
+
             desktop_file_config = configparser.RawConfigParser()
             desktop_file_config.read(desktop_file)
 
@@ -120,15 +121,15 @@ class Application:
         :param in_session: Start application via command in session.
         """
 
-        kill = None
-        in_session = None
+        kill_override = self.kill
+        in_session = False
 
         for key, val in kwargs.items():
             if "session" in str(key).lower():
                 in_session = val
 
             if "kill" in str(key).lower():
-                kill = val
+                kill_override = val
 
         if self.logging:
             log.info("".join((
@@ -136,8 +137,6 @@ class Application:
                 f"start_via_command(self, command={command}, in_session={in_session})"
             )))
 
-        kill_override = kill if kill else self.kill
-
         if self.is_running() and kill_override:
             self.kill_application()
 
